@@ -1,6 +1,6 @@
 // Descriptor wallet library extending bitcoin & miniscript functionality
 // by LNP/BP Association (https://lnp-bp.org)
-// Written in 2020-2021 by
+// Written in 2020-2022 by
 //     Dr. Maxim Orlovsky <orlovsky@pandoracore.com>
 //
 // To the extent possible under law, the author(s) have dedicated all
@@ -17,6 +17,7 @@
 // Coding conventions
 #![recursion_limit = "256"]
 #![deny(dead_code, /* missing_docs, */ warnings)]
+#![allow(clippy::init_numbered_fields)]
 
 //! General workflow for working with ScriptPubkey* types:
 //! ```text
@@ -30,23 +31,16 @@ extern crate amplify;
 #[macro_use]
 extern crate strict_encoding;
 
-mod contract;
-mod deduction;
-mod derive;
-mod generator;
-mod legacy;
-mod script;
-mod typesystem;
+mod descriptor;
+mod input;
+pub mod locks;
+#[cfg(feature = "miniscript")]
+mod templates;
 
-pub use contract::{CompiledMiniscript, ContractDescriptor, ContractType};
-pub use deduction::{Deduce, DeductionError};
-pub use derive::DeriveLockScript;
-pub use generator::{Generator, GeneratorParseError};
-pub use legacy::{MultiSig, SingleSig, Template};
-pub use script::{
-    ScriptConstruction, ScriptSource, ScriptSourceFormat, ScriptTemplate,
-};
-pub use typesystem::{
-    Compact, ContentType, Error, Expanded, FullType, InnerType, OuterType,
-    ParseError, Variants,
+pub use descriptor::{
+    BareDescriptor, CompositeDescrType, DescrVariants, Error, InnerDescrType, OuterDescrType,
+    ParseError, ScriptPubkeyDescr, SpkClass, UnsupportedScriptPubkey,
 };
+pub use input::InputDescriptor;
+#[cfg(feature = "miniscript")]
+pub use templates::ScriptTemplate;
